# ditalini
A modern template for your awesome C++ scientific computing software app/library with wrappers for Python

Philip Mocz (2024)
Flatiron Institute

To install the project:

```console
mkdir build
cd build
cmake ..
make
make install
```

Documentation can be generated with

```console
make doc
```